/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
#include <activemq/connector/openwire/commands/SubscriptionInfo.h>
#include <activemq/exceptions/ActiveMQException.h>
#include <decaf/lang/exceptions/NullPointerException.h>

using namespace std;
using namespace activemq;
using namespace activemq::exceptions;
using namespace activemq::connector;
using namespace activemq::connector::openwire;
using namespace activemq::connector::openwire::commands;
using namespace decaf::lang::exceptions;

/*
 *
 *  Command and marshaling code for OpenWire format for SubscriptionInfo
 *
 *
 *  NOTE!: This file is autogenerated - do not modify!
 *         if you need to make a change, please see the Java Classes in the
 *         activemq-core module
 *
 */
////////////////////////////////////////////////////////////////////////////////
SubscriptionInfo::SubscriptionInfo()
{
    this->clientId = "";
    this->destination = NULL;
    this->selector = "";
    this->subcriptionName = "";
}

////////////////////////////////////////////////////////////////////////////////
SubscriptionInfo::~SubscriptionInfo()
{
    delete this->destination;
}

////////////////////////////////////////////////////////////////////////////////
SubscriptionInfo* SubscriptionInfo::cloneDataStructure() const {
    SubscriptionInfo* subscriptionInfo = new SubscriptionInfo();

    // Copy the data from the base class or classes
    subscriptionInfo->copyDataStructure( this );

    return subscriptionInfo;
}

////////////////////////////////////////////////////////////////////////////////
void SubscriptionInfo::copyDataStructure( const DataStructure* src ) {

    // Copy the data of the base class or classes
    BaseDataStructure::copyDataStructure( src );

    const SubscriptionInfo* srcPtr = dynamic_cast<const SubscriptionInfo*>( src );

    if( srcPtr == NULL || src == NULL ) {
    
        throw decaf::lang::exceptions::NullPointerException(
            __FILE__, __LINE__,
            "SubscriptionInfo::copyDataStructure - src is NULL or invalid" );
    }
    this->setClientId( srcPtr->getClientId() );
    if( srcPtr->getDestination() != NULL ) {
        this->setDestination( 
            dynamic_cast<ActiveMQDestination*>( 
                srcPtr->getDestination()->cloneDataStructure() ) );
    }
    this->setSelector( srcPtr->getSelector() );
    this->setSubcriptionName( srcPtr->getSubcriptionName() );
}

////////////////////////////////////////////////////////////////////////////////
unsigned char SubscriptionInfo::getDataStructureType() const {
    return SubscriptionInfo::ID_SUBSCRIPTIONINFO; 
}

////////////////////////////////////////////////////////////////////////////////
std::string SubscriptionInfo::toString() const {

    ostringstream stream;

    stream << "Begin Class = SubscriptionInfo" << std::endl;
    stream << " Value of SubscriptionInfo::ID_SUBSCRIPTIONINFO = 55" << std::endl; 
    stream << " Value of ClientId = " << this->getClientId() << std::endl;
    stream << " Value of Destination is Below:" << std::endl;
    if( this->getDestination() != NULL ) {
        stream << this->getDestination()->toString() << std::endl;
    } else {
        stream << "   Object is NULL" << std::endl;
    }
    stream << " Value of Selector = " << this->getSelector() << std::endl;
    stream << " Value of SubcriptionName = " << this->getSubcriptionName() << std::endl;
    stream << BaseDataStructure::toString();
    stream << "End Class = SubscriptionInfo" << std::endl;

    return stream.str();
}

////////////////////////////////////////////////////////////////////////////////
bool SubscriptionInfo::equals( const DataStructure* value ) const {
    const SubscriptionInfo* valuePtr = dynamic_cast<const SubscriptionInfo*>( value );

    if( valuePtr == NULL || value == NULL ) {
        return false;
    }
    if( this->getClientId() != valuePtr->getClientId() ) {
        return false;
    }
    if( this->getDestination() != NULL ) {
        if( !this->getDestination()->equals( valuePtr->getDestination() ) ) {
            return false;
        }
    } else if( valuePtr->getDestination() != NULL ) {
        return false;
    }
    if( this->getSelector() != valuePtr->getSelector() ) {
        return false;
    }
    if( this->getSubcriptionName() != valuePtr->getSubcriptionName() ) {
        return false;
    }
    if( !BaseDataStructure::equals( value ) ) {
        return false;
    }
    return true;
}

////////////////////////////////////////////////////////////////////////////////
const std::string& SubscriptionInfo::getClientId() const {
    return clientId;
}

////////////////////////////////////////////////////////////////////////////////
std::string& SubscriptionInfo::getClientId() {
    return clientId;
}

////////////////////////////////////////////////////////////////////////////////
void SubscriptionInfo::setClientId(const std::string& clientId ) {
    this->clientId = clientId;
}

////////////////////////////////////////////////////////////////////////////////
const ActiveMQDestination* SubscriptionInfo::getDestination() const {
    return destination;
}

////////////////////////////////////////////////////////////////////////////////
ActiveMQDestination* SubscriptionInfo::getDestination() {
    return destination;
}

////////////////////////////////////////////////////////////////////////////////
void SubscriptionInfo::setDestination(ActiveMQDestination* destination ) {
    this->destination = destination;
}

////////////////////////////////////////////////////////////////////////////////
const std::string& SubscriptionInfo::getSelector() const {
    return selector;
}

////////////////////////////////////////////////////////////////////////////////
std::string& SubscriptionInfo::getSelector() {
    return selector;
}

////////////////////////////////////////////////////////////////////////////////
void SubscriptionInfo::setSelector(const std::string& selector ) {
    this->selector = selector;
}

////////////////////////////////////////////////////////////////////////////////
const std::string& SubscriptionInfo::getSubcriptionName() const {
    return subcriptionName;
}

////////////////////////////////////////////////////////////////////////////////
std::string& SubscriptionInfo::getSubcriptionName() {
    return subcriptionName;
}

////////////////////////////////////////////////////////////////////////////////
void SubscriptionInfo::setSubcriptionName(const std::string& subcriptionName ) {
    this->subcriptionName = subcriptionName;
}

